from argparse import ArgumentParser
from importlib_metadata import version
from urllib.parse import quote

from .tree import Nistree
from .cli import Niscli
from .adlar import Nisadlar
from .request import req


# parse arguments
argparser = ArgumentParser(prog="nisanyan_cli")
argparser.add_argument(
    "word",
    type=str,
    nargs="*",
    help="<word>",
)
argparser.add_argument(
    "-t",
    "--tree",
    action="store_true",
    default=False,
    help="show result as etymology tree",
)
argparser.add_argument(
    "-r",
    "--random",
    action="store_true",
    default=False,
    help="selects a random word and brings the result",
)
argparser.add_argument(
    "-p",
    "--plain",
    action="store_true",
    default=False,
    help="plain text output",
)
argparser.add_argument(
    "-ad",
    action="store_true",
    default=False,
    help="show result from nisanyanadlar",
)
argparser.add_argument(
    "-v",
    "--version",
    action="version",
    version=f"nisanyan-cli {version('nisanyan-cli')}",
)
args = argparser.parse_args()


def close_words(word, request):
    from rich import print

    clr = 238
    fiveBefore, fiveAfter = [], []
    for b, a in zip(request["fiveBefore"][::-1], request["fiveAfter"]):
        clr = clr - 25
        fiveBefore.append(f"[rgb({clr},{clr},{clr})]" + b["name"] + "[/]")
        fiveAfter.append(f"[rgb({clr},{clr},{clr})]" + a["name"] + "[/]")
    print("[i cyan]Kelime bulunamadı. Yakın sonuçlar:[/]")
    print(
        f'{", ".join(fiveBefore[::-1])}, {request["words"][0]["name"]}, {", ".join(fiveAfter)}'
    )
    print()


def cli():
    if args.ad:
        name = " ".join(args.word)
        Nisadlar(name, args.random)
    elif args.word:
        word = " ".join(args.word)
        request = req(quote(word))
        if request["isUnsuccessful"]:
            close_words(word, request)
            exit()
        if not args.tree:
            Niscli(word, request, args.plain)
        else:
            Nistree(word, request)
    elif args.random:
        word = req("nonexistword")["randomWord"]["name"]
        request = req(quote(word))
        if not args.tree:
            Niscli(word, request, args.plain)
        else:
            Nistree(word, request)


if __name__ == "__main__":
    cli()



from rich import print
from rich.tree import Tree
from urllib.parse import quote
from ._langlist import lang_dict
from ._utils import replace_chars


class Nistree:
    def __init__(self, word, request):
        self.word = quote(word)
        self.request = request
        self.print_tree()

    def print_tree(self):
        sublist = ["bileşik sözcük", "bileşik sözcüğün devamı", "veya"]
        word = self.request["words"]
        for idx, word in enumerate(word):
            tree = Tree(
                f'{self.request["words"][idx]["name"]} [cyan](Günümüz Türkçesi)[/]'
            )
            lst = []
            try:
                for i in word["etymologies"]:
                    lang = i["languages"][0]["name"]
                    dil = (
                        f"({lang})"
                        if lang not in lang_dict
                        else (
                            f'[cyan]([link={lang_dict[lang]["wiki_link"]}]'
                            + lang_dict[lang]["name"]
                            + "[/link]"
                            + f' {lang_dict[lang]["era"]})'
                        )
                    )
                    lst.append(
                        (
                            (
                                f'[i cyan][link=https://www.nisanyansozluk.com/ek/{quote(i["affixes"]["prefix"]["name"])}]'
                                + i["affixes"]["prefix"]["name"]
                                + "[/][/] "
                            )
                            if (i["affixes"] != {} and "prefix" in i["affixes"])
                            else ""
                        )
                        + i["romanizedText"]
                        + (
                            (" ‹" + i["originalText"] + "›")
                            if i["originalText"] != ""
                            else ""
                        )
                        + (
                            (
                                f' [i cyan][link=https://www.nisanyansozluk.com/ek/{quote(i["affixes"]["suffix"]["name"])}]'
                                + i["affixes"]["suffix"]["name"]
                                + "[/][/]"
                            )
                            if (i["affixes"] != {} and "suffix" in i["affixes"])
                            else ""
                        )
                        + f" [cyan]{dil}[/]"
                        + (
                            (": [grey50]" + replace_chars(i["definition"]) + ".[/]")
                            if i["definition"] != ""
                            else ""
                        )
                    )
            except:
                continue

            sub = {}
            sub[lst[0]] = tree.add(lst[0])
            last1 = sub[lst[0]]
            if len(lst) > 1:
                for ix, i in enumerate(lst[1:]):
                    if word["etymologies"][ix + 1]["relation"]["name"] not in sublist:
                        sub[i] = sub[list(sub.keys())[-1]].add(i)
                        last1 = sub[list(sub.keys())[-1]]
                    else:
                        sub[i] = last1.add(i)
            print(tree)
            print()



lang_dict = {
    "Eski Türkçe": {
        "name": "Eski Türkçe",
        "wiki_link": "https://en.wikipedia.org/wiki/Old_Turkic",
        "era": "600—1200",
    },
    "Orta Türkçe": {
        "name": "Orta Türkçe",
        "wiki_link": "https://en.wikipedia.org/wiki/Middle_Turkic_languages",
        "era": "900—1500",
    },
    "Eski Yunanca": {
        "name": "Antik Yunanca",
        "wiki_link": "https://en.wikipedia.org/wiki/Ancient_Greek",
        "era": "MÖ.1500—MS.300",
    },
    "Orta Farsça": {
        "name": "Orta Farsça",
        "wiki_link": "https://en.wikipedia.org/wiki/Middle_Persian",
        "era": "1300—1500",
    },
    "Akatça": {
        "name": "Akatça",
        "wiki_link": "https://en.wikipedia.org/wiki/Akkadian_language",
        "era": "MÖ.2500—MÖ.500",
    },
    "Avestaca": {
        "name": "Avestaca",
        "wiki_link": "https://en.wikipedia.org/wiki/Avestan",
        "era": "MÖ.2000",
    },
    "Eski Fransızca": {
        "name": "Eski Fransızca",
        "wiki_link": "https://en.wikipedia.org/wiki/Old_French",
        "era": "842—1400",
    },
    "Eski İngilizce": {
        "name": "Eski İngilizce",
        "wiki_link": "https://en.wikipedia.org/wiki/Old_English",
        "era": "450—1150",
    },
    "Soğdca": {
        "name": "Soğdca",
        "wiki_link": "https://en.wikipedia.org/wiki/Sogdian_language",
        "era": "MÖ.1000—MS.1000",
    },
    "Hintavrupa Anadili": {
        "name": "Hintavrupa Anadili",
        "wiki_link": "https://en.wikipedia.org/wiki/Proto-Indo-European_language",
        "era": "MS.4500—MS.2500",
    },
}



from rich import print, box
from rich.table import Table
from rich.console import Console
from rich.align import Align
from rich import print
from ._adlar_cache import cache
from urllib.parse import quote
from http.client import HTTPSConnection
import json


def req(name):
    conn = HTTPSConnection("www.nisanyanadlar.com")
    conn.request("GET", f"/api/names/{name}?session=1")
    res = conn.getresponse()
    data = res.read()
    return json.loads(data)


class Nisadlar:
    def __init__(self, name, random: bool = False):
        if not name:
            self.name = "nonexistname"
        else:
            self.name = name.capitalize()

        self.data = req(quote(self.name))
        if random:
            self.name = self.data["randomName"].capitalize()
            self.data = req(quote(self.name))
        elif self.name == "nonexistname":
            exit(1)
        elif not self.data["isSuccessful"]:
            print("Not found!")
            exit(1)

        self.rich_output()

    def rich_output(self):
        for i in self.data["names"]:
            # gender
            gender_ratio = i["genderRatio"]
            female_percentage = gender_ratio * 100
            male_percentage = (1 - gender_ratio) * 100
            gender = f"[pink1]\u2640:{male_percentage:.0f}%[/] [deep_sky_blue1]\u2642:{female_percentage:.0f}% [/]"

            # years
            # Initialize decade counts
            decade_counts = {}
            for year in range(1950, 2030, 10):
                decade_counts[f"{year}s"] = 0

            year_data = {}
            for variant in i["variants"]:
                if i["name"] == variant["name"]:
                    year_data = variant["years"]

            # Count the popularity for each decade
            for year, count in year_data.items():
                year = int(year)
                if year >= 1950 and year < 2030:
                    decade = ((year - 1950) // 10) * 10 + 1950
                    decade_counts[f"{decade}s"] += count

            years = []
            for decade, count in decade_counts.items():
                years.append(f"{decade[-3:]}: {count}")

            table = Table(box=box.ROUNDED, show_footer=True, expand=True)
            table.add_column(
                f'{i["name"]} {gender} [pale_green1]{i["count"]} kişi:[/] [gray19]{", ".join(years)}[/]',
                header_style="bold",
                footer=Align(
                    f'sıklık sırası: {i["rank"]}',
                    vertical="middle",
                    align="center",
                    style="grey42",
                ),
            )
            # cache["nations"] nat_code=yt : cache["languages"] lang_code:t
            table.add_row(
                "[#994E8E]Köken:[/#994E8E]" + "\n" + i["definition"] + "\n"
            ) if i["definition"] else None
            table.add_row((i["note"]) + "\n") if i["note"] else None
            # 0: ulusal t: türkçe alanı
            table.add_row(
                "[#994E8E]Dağılım:[/#994E8E]"
                + "\n"
                + (
                    ", ".join(j["name"] for j in i["region"]["locations"])
                    if i["region"]["locations"] != []
                    else "Ulusal"
                )
                + "\n"
            )
            table.add_row(
                "[#994E8E]Farklı Yazılışlar: (Alfabetik)[/#994E8E]"
                + "\n"
                + ", ".join(
                    [f'{j["name"]} ({j["count"]["total"]})' for j in i["variants"]]
                )
            ) if i["variants"] else None
            table.add_row(
                "[#994E8E]İlgili Adlar:[/#994E8E]" + "\n" + ", ".join(i["relatedNames"])
            ) if i["relatedNames"] else None

            print(table)
        Console().print(
            f"[grey42][link=https://www.nisanyanadlar.com/isim/{quote(self.name)}]nisanyanadlar.com/isim/{self.name}↗[/link]",
            justify="right",
        )



cache = {
    "books": [
        {"book_id": 1, "book_code": "q", "book_display": "Kuran kaynaklı ad"},
        {"book_id": 2, "book_code": "s", "book_display": "Sahabi adı"},
        {"book_id": 3, "book_code": "ş", "book_display": "Şahname kaynaklı ad"},
        {"book_id": 4, "book_code": "t", "book_display": "Tevrat kaynaklı ad"},
        {
            "book_id": 5,
            "book_code": "t q",
            "book_display": "Tevrat ve Kuran kaynaklı ad",
        },
        {"book_id": 6, "book_code": "yt", "book_display": "Yeni Türk adı (1934-35)"},
        {
            "book_id": 7,
            "book_code": "q s",
            "book_display": "Kuran kaynaklı ad, sahabi adı",
        },
        {"book_id": 8, "book_code": "i", "book_display": "İncil kaynaklı ad"},
        {
            "book_id": 9,
            "book_code": "t i",
            "book_display": "Tevrat ve İncil kaynaklı ad",
        },
        {
            "book_id": 10,
            "book_code": "i q",
            "book_display": "İncil ve Kuran kaynaklı ad",
        },
        {"book_id": 11, "book_code": "d", "book_display": "Dede Korkut kaynaklı ad"},
    ],
    "languages": [
        {
            "lang_id": 1,
            "lang_code": "a",
            "lang_display": "Ar",
            "lang_fullname": "Arapça",
        },
        {
            "lang_id": 2,
            "lang_code": "alm",
            "lang_display": "Alm",
            "lang_fullname": "Almanca",
        },
        {
            "lang_id": 3,
            "lang_code": "arn",
            "lang_display": "Arn",
            "lang_fullname": "Arnavutça",
        },
        {
            "lang_id": 4,
            "lang_code": "az",
            "lang_display": "Az",
            "lang_fullname": "Azerice",
        },
        {
            "lang_id": 5,
            "lang_code": "bu",
            "lang_display": "Bul",
            "lang_fullname": "Bulgarca",
        },
        {
            "lang_id": 6,
            "lang_code": "ç",
            "lang_display": "Çr",
            "lang_fullname": "Çerkesçe",
        },
        {
            "lang_id": 7,
            "lang_code": "çin",
            "lang_display": "Çin",
            "lang_fullname": "Çince",
        },
        {
            "lang_id": 8,
            "lang_code": "coğ",
            "lang_display": "coğ",
            "lang_fullname": "Yer veya kavim adı",
        },
        {
            "lang_id": 9,
            "lang_code": "e",
            "lang_display": "Erm",
            "lang_fullname": "Ermenice",
        },
        {
            "lang_id": 10,
            "lang_code": "ealm",
            "lang_display": "EAlm",
            "lang_fullname": "Eski Almanca",
        },
        {
            "lang_id": 11,
            "lang_code": "eing",
            "lang_display": "Eİng",
            "lang_fullname": "Eski Anglosaksonca",
        },
        {
            "lang_id": 12,
            "lang_code": "f",
            "lang_display": "Fa",
            "lang_fullname": "Farsça",
        },
        {
            "lang_id": 13,
            "lang_code": "fr",
            "lang_display": "Fr",
            "lang_fullname": "Fransızca",
        },
        {
            "lang_id": 14,
            "lang_code": "g",
            "lang_display": "Gü",
            "lang_fullname": "Gürcüce",
        },
        {
            "lang_id": 15,
            "lang_code": "ger",
            "lang_display": "Ger",
            "lang_fullname": "Germence",
        },
        {
            "lang_id": 16,
            "lang_code": "h",
            "lang_display": "Hint",
            "lang_fullname": "Hintçe",
        },
        {
            "lang_id": 17,
            "lang_code": "ib",
            "lang_display": "İbr",
            "lang_fullname": "İbranice",
        },
        {
            "lang_id": 18,
            "lang_code": "ing",
            "lang_display": "İng",
            "lang_fullname": "İngilizce",
        },
        {
            "lang_id": 19,
            "lang_code": "irl",
            "lang_display": "İrl",
            "lang_fullname": "İrlandaca",
        },
        {
            "lang_id": 20,
            "lang_code": "isp",
            "lang_display": "İsp",
            "lang_fullname": "İspanyolca",
        },
        {
            "lang_id": 21,
            "lang_code": "isv",
            "lang_display": "İsv",
            "lang_fullname": "İsveççe",
        },
        {
            "lang_id": 22,
            "lang_code": "it",
            "lang_display": "İt",
            "lang_fullname": "İtalyanca",
        },
        {
            "lang_id": 23,
            "lang_code": "k",
            "lang_display": "Kr",
            "lang_fullname": "Kürtçe",
        },
        {
            "lang_id": 24,
            "lang_code": "kaz",
            "lang_display": "Kaz",
            "lang_fullname": "Kazakça",
        },
        {
            "lang_id": 25,
            "lang_code": "krg",
            "lang_display": "Krg",
            "lang_fullname": "Kırgızca",
        },
        {
            "lang_id": 26,
            "lang_code": "lat",
            "lang_display": "Lat",
            "lang_fullname": "Latince",
        },
        {
            "lang_id": 27,
            "lang_code": "lz",
            "lang_display": "Laz",
            "lang_fullname": "Lazca",
        },
        {
            "lang_id": 28,
            "lang_code": "mac",
            "lang_display": "Mac",
            "lang_fullname": "Macarca",
        },
        {
            "lang_id": 29,
            "lang_code": "moğ",
            "lang_display": "Moğ",
            "lang_fullname": "Moğolca",
        },
        {
            "lang_id": 30,
            "lang_code": "nor",
            "lang_display": "Nor",
            "lang_fullname": "Eski Norsça (Viking dili)",
        },
        {
            "lang_id": 31,
            "lang_code": "öz",
            "lang_display": "öz",
            "lang_fullname": "kişi adı",
        },
        {
            "lang_id": 32,
            "lang_code": "r",
            "lang_display": "Rus",
            "lang_fullname": "Rusça",
        },
        {
            "lang_id": 33,
            "lang_code": "ro",
            "lang_display": "Rom",
            "lang_fullname": "Romence",
        },
        {
            "lang_id": 34,
            "lang_code": "s",
            "lang_display": "Sür",
            "lang_fullname": "Süryanice",
        },
        {
            "lang_id": 35,
            "lang_code": "srp",
            "lang_display": "Srp",
            "lang_fullname": "Sırp/Hırvatça",
        },
        {
            "lang_id": 36,
            "lang_code": "t",
            "lang_display": "Tr",
            "lang_fullname": "Türkçe",
        },
        {
            "lang_id": 37,
            "lang_code": "x",
            "lang_display": "Tr+",
            "lang_fullname": "Türkçe (karışık)",
        },
        {
            "lang_id": 38,
            "lang_code": "yt",
            "lang_display": "YTr",
            "lang_fullname": "Yeni Türkçe",
        },
        {
            "lang_id": 39,
            "lang_code": "ef",
            "lang_display": "İr",
            "lang_fullname": "Eski İran dilleri",
        },
        {
            "lang_id": 40,
            "lang_code": "akad",
            "lang_display": "Akad",
            "lang_fullname": "Akatça",
        },
        {
            "lang_id": 41,
            "lang_code": "fen",
            "lang_display": "Fen",
            "lang_fullname": "Fenike dili",
        },
        {
            "lang_id": 42,
            "lang_code": "fin",
            "lang_display": "Fin",
            "lang_fullname": "Fince",
        },
        {
            "lang_id": 43,
            "lang_code": "tat",
            "lang_display": "Tat",
            "lang_fullname": "Tatarca",
        },
        {
            "lang_id": 44,
            "lang_code": "uk",
            "lang_display": "Ukr",
            "lang_fullname": "Ukrayna dili",
        },
        {
            "lang_id": 45,
            "lang_code": "ey",
            "lang_display": "EYun",
            "lang_fullname": "Eski Yunanca",
        },
        {
            "lang_id": 46,
            "lang_code": "y",
            "lang_display": "Yun",
            "lang_fullname": "Yunanca",
        },
        {
            "lang_id": 47,
            "lang_code": "mıs",
            "lang_display": "Mıs",
            "lang_fullname": "Eski Mısır dili",
        },
        {
            "lang_id": 48,
            "lang_code": "et",
            "lang_display": "ETr",
            "lang_fullname": "Eski Türkçe",
        },
        {
            "lang_id": 49,
            "lang_code": "ar",
            "lang_display": "Aram",
            "lang_fullname": "Arami/Süryanice",
        },
        {
            "lang_id": 52,
            "lang_code": "hol",
            "lang_display": "Hol",
            "lang_fullname": "Hollandaca",
        },
        {
            "lang_id": 54,
            "lang_code": "z",
            "lang_display": "Zaz",
            "lang_fullname": "Zazaca",
        },
        {
            "lang_id": 55,
            "lang_code": "br",
            "lang_display": "Bret",
            "lang_fullname": "Bretonca",
        },
        {
            "lang_id": 56,
            "lang_code": "eh",
            "lang_display": "EHind",
            "lang_fullname": "Eski Hintçe",
        },
        {
            "lang_id": 57,
            "lang_code": "pol",
            "lang_display": "Pol",
            "lang_fullname": "Polonya dili",
        },
        {
            "lang_id": 58,
            "lang_code": "gael",
            "lang_display": "Gael",
            "lang_fullname": "İskoç Gaelcesi",
        },
        {
            "lang_id": 59,
            "lang_code": "jap",
            "lang_display": "Jap",
            "lang_fullname": "Japonca",
        },
        {
            "lang_id": 60,
            "lang_code": "çağ",
            "lang_display": "ÇağT",
            "lang_fullname": "Çağatay Türkçesi",
        },
        {
            "lang_id": 61,
            "lang_code": "efr",
            "lang_display": "EFr",
            "lang_fullname": "Eski Fransızca",
        },
        {
            "lang_id": 62,
            "lang_code": "sl",
            "lang_display": "Slav",
            "lang_fullname": "Slavca",
        },
        {
            "lang_id": 63,
            "lang_code": "sogd",
            "lang_display": "Sogd",
            "lang_fullname": "Sogdca",
        },
        {
            "lang_id": 64,
            "lang_code": "sum",
            "lang_display": "Sumer",
            "lang_fullname": "Sumerce",
        },
        {
            "lang_id": 65,
            "lang_code": "hit",
            "lang_display": "Hit",
            "lang_fullname": "Hititçe",
        },
        {
            "lang_id": 66,
            "lang_code": "gal",
            "lang_display": "Gal",
            "lang_fullname": "Gal dili (Welsh)",
        },
        {
            "lang_id": 67,
            "lang_code": "özb",
            "lang_display": "Özb",
            "lang_fullname": "Özbekçe",
        },
    ],
    "nations": [
        {"nat_id": 1, "nat_code": "e", "nat_name": "Ermeni", "nat_gm": 1},
        {"nat_id": 2, "nat_code": "y", "nat_name": "Rum", "nat_gm": 1},
        {"nat_id": 3, "nat_code": "g", "nat_name": "Gürcü", "nat_gm": 0},
        {"nat_id": 4, "nat_code": "j", "nat_name": "Yahudi", "nat_gm": 1},
        {"nat_id": 5, "nat_code": "f", "nat_name": "Batı Avrupa", "nat_gm": 1},
        {"nat_id": 6, "nat_code": "k", "nat_name": "Kürt", "nat_gm": 0},
        {"nat_id": 7, "nat_code": "ar", "nat_name": "Arap", "nat_gm": 0},
        {"nat_id": 8, "nat_code": "s", "nat_name": "Süryani", "nat_gm": 1},
        {"nat_id": 9, "nat_code": "ah", "nat_name": "Ahıska", "nat_gm": 0},
        {"nat_id": 10, "nat_code": "az", "nat_name": "Azeri", "nat_gm": 0},
        {"nat_id": 11, "nat_code": "loc", "nat_name": "Yerel", "nat_gm": 0},
        {"nat_id": 12, "nat_code": "ha", "nat_name": "Hristiyan Arap", "nat_gm": 1},
        {"nat_id": 13, "nat_code": "al", "nat_name": "Alevi", "nat_gm": 0},
        {
            "nat_id": 14,
            "nat_code": "nu",
            "nat_name": "Nusayri (Arap Alevi)",
            "nat_gm": 1,
        },
        {"nat_id": 15, "nat_code": "drs", "nat_name": "Dersimli", "nat_gm": 0},
        {"nat_id": 16, "nat_code": "rg", "nat_name": "Rumeli göçmeni", "nat_gm": 0},
        {"nat_id": 17, "nat_code": "r", "nat_name": "Doğu Avrupa", "nat_gm": 1},
        {"nat_id": 18, "nat_code": "ç", "nat_name": "Çerkes", "nat_gm": 0},
        {"nat_id": 19, "nat_code": "h", "nat_name": "Hint", "nat_gm": 1},
        {"nat_id": 20, "nat_code": "kp", "nat_name": "Terekeme/Karapapak", "nat_gm": 0},
        {"nat_id": 21, "nat_code": "arn", "nat_name": "Arnavut", "nat_gm": 0},
        {"nat_id": 23, "nat_code": "oa", "nat_name": "Orta Asya/Afgan", "nat_gm": 0},
        {"nat_id": 24, "nat_code": "ro", "nat_name": "Romen", "nat_gm": 1},
        {"nat_id": 25, "nat_code": "lz", "nat_name": "Laz", "nat_gm": 0},
        {"nat_id": 27, "nat_code": "bo", "nat_name": "Boşnak", "nat_gm": 0},
        {"nat_id": 28, "nat_code": "gm", "nat_name": "Gayrimüslim", "nat_gm": 0},
        {"nat_id": 30, "nat_code": "rs", "nat_name": "Rus ve Sovyet", "nat_gm": 0},
        {
            "nat_id": 31,
            "nat_code": "yg",
            "nat_name": "Makedonya/Kosova/Bosna göçmeni",
            "nat_gm": 0,
        },
        {
            "nat_id": 32,
            "nat_code": "bg",
            "nat_name": "Bulgaristan göçmeni",
            "nat_gm": 0,
        },
        {"nat_id": 33, "nat_code": "z", "nat_name": "Zaza", "nat_gm": 0},
        {"nat_id": 34, "nat_code": "bu", "nat_name": "Bulgar", "nat_gm": 0},
        {"nat_id": 35, "nat_code": "ir", "nat_name": "İranlı", "nat_gm": 0},
        {"nat_id": 36, "nat_code": "uk", "nat_name": "Ukrayna", "nat_gm": 0},
        {"nat_id": 37, "nat_code": "çç", "nat_name": "Çeçen/Dağıstanlı", "nat_gm": 0},
        {"nat_id": 39, "nat_code": "t", "nat_name": "Türk", "nat_gm": 0},
        {"nat_id": 41, "nat_code": "tat", "nat_name": "Tatar", "nat_gm": 0},
        {
            "nat_id": 42,
            "nat_code": "yt",
            "nat_name": "Yeni Türk adı (1934-35)",
            "nat_gm": 0,
        },
        {"nat_id": 43, "nat_code": "uyg", "nat_name": "Uygur", "nat_gm": 0},
        {"nat_id": 44, "nat_code": "ak", "nat_name": "Alevi/Kürt", "nat_gm": 0},
    ],
}



from rich import print, box
from rich.table import Table
from rich.console import Console
from rich.align import Align
from urllib.parse import quote
from .request import req
from ._utils import *

TITLES = {
    "koken": "Köken:",
    "daha_fazla": "Daha fazla bilgi için",
    "ek_aciklama": "Ek Açıklama:",
    "benzer_sozcukler": "Benzer Sözcükler:",
    "maddeye_gonderenler": "Bu maddeye gönderenler:",
    "tarihce": "Tarihçe: (tespit edilen en eski Türkçe kaynak ve diğer örnekler)",
    "son_guncelleme": "Son Güncelleme",
}


class Niscli:
    def __init__(self, word, request, plain):
        self.word = word
        self.request = request
        if plain:
            self.print_plain()
            exit()
        self.print_rich()

    def get_data(self):
        output = {}
        data = self.request
        for i in data["words"]:
            # Köken
            try:
                lst = []
                koken = ""
                for j in i["etymologies"]:
                    txt = (
                        f'[b]{j["languages"][0]["name"]}[/] [i]{j["romanizedText"]}[/] {(j["originalText"]+" " if j["originalText"]!=""else"")}'
                        + ("“" + j["definition"] + "”" if j["definition"] != "" else "")
                    )
                    lst.append(txt)
                for j in lst:
                    koken = koken + j + ". "
            except:
                koken = None
            # Daha fazla
            try:
                daha_fazla = [j["name"] for j in i["references"]]
            except:
                daha_fazla = []
            # Bu maddeye gönderenler
            try:
                maddeye_gonderenler = [j["name"] for j in i["referenceOf"]]
            except:
                maddeye_gonderenler = []
            # Tarihçe
            try:
                lst = []
                tarihce = ""
                for j in i["histories"]:
                    txt = (
                        (f'{j["language"]["name"]}: ' if "language" in j else "")
                        + (f'"{j["definition"]}" ' if j["definition"] != "" else "")
                        + (f'[i]{j["excerpt"]}[/] ' if j["excerpt"] != "" else "")
                        + f'[grey50][{(j["source"]["name"]+", ") if j["source"]["name"]!=""else ""}{j["source"]["book"]}, {j["date"]}][/]'
                    )
                    quote = replace_chars(
                        j["quote"].replace("[", "〔").replace("]", "〕")
                    )
                    lst.append([txt, quote])
                for j in lst:
                    tarihce = (
                        tarihce
                        + j[0]
                        + (f"\n  [i]{j[1]}[/]" if j[1] != "" else "")
                        + ("\n" if j != lst[-1] else "")
                    )
            except:
                tarihce = None

            output[i["name"]] = {
                "koken": replace_chars(koken) if koken else None,
                "daha_fazla": daha_fazla,
                "ek_aciklama": replace_chars(i["note"]) if i["note"] else None,
                "benzer_sozcukler": [j for j in i["queries"] if j != i["name"]],
                "maddeye_gonderenler": maddeye_gonderenler,
                "tarihce": tarihce,
                "son_guncelleme": date_convert(i["timeUpdated"][:10]),
            }
        return output

    def print_rich(self):
        data = self.get_data()
        data2 = {}
        for i in data:
            data2[i] = {}
            for j in data[i]:
                if data[i][j]:
                    data2[i][j] = data[i][j]
        data = data2

        for i in data:
            table = Table(box=box.ROUNDED, show_footer=True, expand=True)
            table.add_column(
                i,
                header_style="bold",
                footer=Align(
                    data[i]["son_guncelleme"],
                    vertical="middle",
                    align="right",
                    style="grey42",
                ),
            )
            for jx, j in enumerate(data[i]):
                newline = "" if jx == len(list(data[i].keys())) - 2 else "\n"
                if j == "son_guncelleme":
                    continue
                if j == "daha_fazla" and data[i][j]:
                    table.add_row(
                        f"{TITLES[j]} [cornflower_blue]"
                        + "[/], [cornflower_blue]".join(data[i][j])
                        + "[/] "
                        + ("maddesine" if len(data[i][j]) == 1 else "maddelerine")
                        + " bakınız."
                        + newline
                    )
                    continue
                if data[i][j]:
                    content = data[i][j]
                    title = f"[#994E8E]{TITLES[j]}[/#994E8E]\n"
                    table.add_row(
                        title
                        + (
                            content
                            if type(content) != list
                            else ", ".join(content[:20])
                        )
                        + newline
                    )
            print(table)

        Console().print(
            f"[grey42][link=https://www.nisanyansozluk.com/kelime/{quote(self.word)}]nisanyansozluk.com/kelime/{self.word}↗[/link]",
            justify="right",
        )

    def print_plain(self):
        data = self.get_data()
        console = Console(no_color=True)
        for i in data:
            console.print(f":::...{i}...:::")
            for j in data[i]:
                elem = data[i][j]
                if j == "son_guncelleme":
                    continue
                if j == "daha_fazla" and elem:
                    console.print(
                        f"{TITLES[j]} "
                        + ", ".join(elem)
                        + (" maddesine" if len(elem) == 1 else " maddelerine")
                        + " bakınız.\n"
                    )
                    continue
                if elem:
                    elem = elem if type(elem) != list else ", ".join(elem)
                    console.print(f"{TITLES[j]}\n{elem}\n") if elem else None



def replace_chars(text):
    return (
        text.replace("%b", "")
        .replace("%i", "")
        .replace("%u", "")
        .replace("%l", "")
        .replace("ETü", "Eski Türkçe")
        .replace("a.a.", "aynı anlam")
    )


def date_convert(date):
    aylar = {
        "01": "Ocak",
        "02": "Şubat",
        "03": "Mart",
        "04": "Nisan",
        "05": "Mayıs",
        "06": "Haziran",
        "07": "Temmuz",
        "08": "Ağustos",
        "09": "Eylül",
        "10": "Ekim",
        "11": "Kasım",
        "12": "Aralık",
    }
    date = date.split("-")
    return date[2] + " " + aylar[date[1]] + " " + date[0]



from http.client import HTTPSConnection
from json import loads


def req(word):
    conn = HTTPSConnection("www.nisanyansozluk.com")
    conn.request("GET", f"/api/words/{word}?session=1")
    res = conn.getresponse()
    data = res.read()
    return loads(data)
